bl_info = {
    "name": "GP Render",
    "description": "Organise export of gp layers through compositor output",
    "author": "Samuel Bernou",
    "version": (1, 6, 3),
    "blender": (3, 0, 0),
    "location": "View3D",
    "warning": "",
    "doc_url": "https://gitlab.com/autour-de-minuit/blender/gp_render",
    "tracker_url": "https://gitlab.com/autour-de-minuit/blender/gp_render/-/issues",
    "category": "Object" }


from . import OP_add_layer
from . import OP_merge_layers
from . import OP_clear
from . import OP_clean
from . import OP_connect_toggle
from . import OP_manage_outputs
from . import OP_scene_switch
from . import OP_crop_to_object
from . import OP_render_scenes
from . import OP_check_scene
from . import OP_post_render
from . import OP_render_pdf
from . import OP_export_to_ae
from . import prefs
from . import OP_setup_layers
from . import OP_auto_build
from . import ui

from .fn import scene_aa

bl_modules = (
    prefs,
    OP_add_layer,
    OP_clear,
    OP_clean,
    OP_connect_toggle,
    OP_merge_layers,
    OP_manage_outputs,
    OP_scene_switch,
    OP_crop_to_object,
    OP_render_scenes,
    OP_check_scene,
    OP_post_render,
    OP_render_pdf,
    OP_export_to_ae,
    OP_setup_layers,
    OP_auto_build,
    ui,
)

def update_scene_aa(context, scene):
    scene_aa(toggle=bpy.context.scene.use_aa)

import bpy

def register():
    # if bpy.app.background:
    #     return

    for mod in bl_modules:
        mod.register()

    # bpy.types.Scene.pgroup_name = bpy.props.PointerProperty(type = PROJ_PGT_settings)
    bpy.types.Scene.use_aa = bpy.props.BoolProperty(
        name='Use Native Anti Aliasing',
        default=True,
        description='\
Should be Off only if tree contains a merge_NG or alpha-over-combined renderlayers.\n\
Auto-set to Off when using node merge button\n\
Toggle: AA settings of and muting AA nested-nodegroup',
        update=update_scene_aa)

def unregister():
    # if bpy.app.background:
    #     return

    for mod in reversed(bl_modules):
        mod.unregister()

    del bpy.types.Scene.use_aa

if __name__ == "__main__":
    register()